/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import type { ExclusiveMapTree, SchemaAndPolicy } from "../core/index.js";
import { type FlexTreeContext, type FlexTreeHydratedContext } from "../feature-libraries/index.js";
import type { ImplicitAllowedTypes, ImplicitFieldSchema } from "./schemaTypes.js";
import { type InsertableContent } from "./toMapTree.js";
/**
 * Prepare content from a user for insertion into a tree.
 * @remarks
 * This validates and converts the input, and if necessary invokes {@link prepareContentForHydration}.
 */
export declare function prepareForInsertion<TIn extends InsertableContent | undefined>(data: TIn, schema: ImplicitFieldSchema, destinationContext: FlexTreeContext): TIn extends undefined ? undefined : ExclusiveMapTree;
/**
 * {@link prepareForInsertion} but batched for array content.
 * @privateRemarks
 * TODO:
 * Experimentally it was determined that making separate calls to prepareContentForHydration for each array item did not work.
 * This should be understood and fixed or have the factors that cause it clearly documented.
 * If fixed, this function should be removed, and arrays can just map over prepareForInsertion.
 */
export declare function prepareArrayForInsertion(data: readonly InsertableContent[], schema: ImplicitAllowedTypes, destinationContext: FlexTreeContext): ExclusiveMapTree[];
/**
 * Split out from {@link prepareForInsertion} as to allow use without a context.
 * @remarks
 * Adding this entry point is a workaround for initialize not currently having a context.
 */
export declare function prepareForInsertionContextless<TIn extends InsertableContent | undefined>(data: TIn, schema: ImplicitFieldSchema, schemaAndPolicy: SchemaAndPolicy, hydratedData: Pick<FlexTreeHydratedContext, "checkout" | "nodeKeyManager"> | undefined): TIn extends undefined ? undefined : ExclusiveMapTree;
//# sourceMappingURL=prepareForInsertion.d.ts.map